TileTool is a simple, base module for working with tiles, based on pygame.sprite.Sprite. 
With TileTool you can transfer tile-levels and drawings from different format files to tile games created on pygame. 
https://tiletool.readthedocs.io/en/latest/ - module documentation
